datastructuretools.TreeContainer
================================

.. abjad-lineage:: abjad.tools.datastructuretools.TreeContainer.TreeContainer

.. autoclass:: abjad.tools.datastructuretools.TreeContainer.TreeContainer

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.datastructuretools.TreeContainer.TreeContainer.append
      ~abjad.tools.datastructuretools.TreeContainer.TreeContainer.children
      ~abjad.tools.datastructuretools.TreeContainer.TreeContainer.depth
      ~abjad.tools.datastructuretools.TreeContainer.TreeContainer.depthwise_inventory
      ~abjad.tools.datastructuretools.TreeContainer.TreeContainer.extend
      ~abjad.tools.datastructuretools.TreeContainer.TreeContainer.graph_order
      ~abjad.tools.datastructuretools.TreeContainer.TreeContainer.improper_parentage
      ~abjad.tools.datastructuretools.TreeContainer.TreeContainer.index
      ~abjad.tools.datastructuretools.TreeContainer.TreeContainer.insert
      ~abjad.tools.datastructuretools.TreeContainer.TreeContainer.leaves
      ~abjad.tools.datastructuretools.TreeContainer.TreeContainer.name
      ~abjad.tools.datastructuretools.TreeContainer.TreeContainer.nodes
      ~abjad.tools.datastructuretools.TreeContainer.TreeContainer.parent
      ~abjad.tools.datastructuretools.TreeContainer.TreeContainer.pop
      ~abjad.tools.datastructuretools.TreeContainer.TreeContainer.proper_parentage
      ~abjad.tools.datastructuretools.TreeContainer.TreeContainer.remove
      ~abjad.tools.datastructuretools.TreeContainer.TreeContainer.root
      ~abjad.tools.datastructuretools.TreeContainer.TreeContainer.__contains__
      ~abjad.tools.datastructuretools.TreeContainer.TreeContainer.__copy__
      ~abjad.tools.datastructuretools.TreeContainer.TreeContainer.__deepcopy__
      ~abjad.tools.datastructuretools.TreeContainer.TreeContainer.__delitem__
      ~abjad.tools.datastructuretools.TreeContainer.TreeContainer.__eq__
      ~abjad.tools.datastructuretools.TreeContainer.TreeContainer.__format__
      ~abjad.tools.datastructuretools.TreeContainer.TreeContainer.__getitem__
      ~abjad.tools.datastructuretools.TreeContainer.TreeContainer.__hash__
      ~abjad.tools.datastructuretools.TreeContainer.TreeContainer.__iter__
      ~abjad.tools.datastructuretools.TreeContainer.TreeContainer.__len__
      ~abjad.tools.datastructuretools.TreeContainer.TreeContainer.__ne__
      ~abjad.tools.datastructuretools.TreeContainer.TreeContainer.__repr__
      ~abjad.tools.datastructuretools.TreeContainer.TreeContainer.__setitem__

Bases
-----

- :py:class:`datastructuretools.TreeNode <abjad.tools.datastructuretools.TreeNode.TreeNode>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.children
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.depth
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.depthwise_inventory
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.graph_order
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.improper_parentage
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.leaves
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.nodes
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.parent
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.proper_parentage
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.root
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.name
   :noindex:

Methods
-------

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.append
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.extend
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.index
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.insert
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.pop
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.remove
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.__contains__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.__copy__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.__deepcopy__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.__delitem__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.__eq__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.__format__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.__getitem__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.__hash__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.__iter__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.__len__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.__ne__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.__repr__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.__setitem__
   :noindex:
